@@ -14,6 +14,7 @@ from typing import Any, Dict, Iterable, List, Optional, Pattern, Union
 from urllib.parse import ParseResult, parse_qs, unquote_plus, urlparse, urlunparse
 
 from pytility import (
+    arg_to_iter,
     clear_list,
     normalize_space,
     parse_float,
@@ -433,6 +434,7 @@ def parse_url(
 ) -> Optional[ParseResult]:
     """ parse URL and optionally filter for hosts """
     url = urlparse(url) if isinstance(url, str) else url
+    hostnames = tuple(arg_to_iter(hostnames))
     return (
         url
         if url
@@ -446,6 +448,21 @@ def parse_url(
     )
 
 
+def validate_url(
+    url: Union[str, ParseResult, None],
+    hostnames: Optional[Iterable[Union[str, Pattern]]] = None,
+    schemes: Optional[Iterable[Union[str, Pattern]]] = None,
+) -> Optional[str]:
+    """Returns cleaned up URL iff valid with scheme, hostname, and path."""
+    url = parse_url(url=url, hostnames=hostnames)
+    schemes = frozenset(arg_to_iter(schemes))
+    return (
+        url.geturl()
+        if url is not None and url.scheme and (not schemes or url.scheme in schemes)
+        else None
+    )
+
+
 def extract_bgg_id(url: Union[str, ParseResult, None]) -> Optional[int]:
     """ extract BGG ID from URL """
     url = parse_url(url, ("boardgamegeek.com", "www.boardgamegeek.com"))
